@@ -10,8 +10,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
-from six import moves
+import importlib
+
+from unittest import mock
 
 from os_vif.internal.ip import api
 from os_vif.tests.unit import base
@@ -21,18 +22,18 @@ class TestIpApi(base.TestCase):
 
     @staticmethod
     def _reload_original_os_module():
-        moves.reload_module(api)
+        importlib.reload(api)
 
     def test_get_impl_windows(self):
         self.addCleanup(self._reload_original_os_module)
         with mock.patch('os.name', 'nt'):
-            moves.reload_module(api)
+            importlib.reload(api)
             from os_vif.internal.ip.windows import impl_netifaces
             self.assertIsInstance(api.ip, impl_netifaces.Netifaces)
 
     def test_get_impl_linux(self):
         self.addCleanup(self._reload_original_os_module)
         with mock.patch('os.name', 'posix'):
-            moves.reload_module(api)
+            importlib.reload(api)
             from os_vif.internal.ip.linux import impl_pyroute2
             self.assertIsInstance(api.ip, impl_pyroute2.PyRoute2)
